#
# spec file for package gcdemu
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __requires_exclude typelib\\(AppIndicator(|3)\\)
Name:           gcdemu
Version:        3.2.6
Release:        1.5
Summary:        GTK+ application for controlling CDEmu daemon
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://cdemu.sourceforge.io/
Source0:        https://sourceforge.net/projects/cdemu/files/gcdemu/gcdemu-%{version}.tar.xz
BuildRequires:  cmake >= 3.7
BuildRequires:  gdk-pixbuf
BuildRequires:  gettext >= 0.15
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool >= 0.21
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-gobject >= 3.0.0
BuildRequires:  update-desktop-files
Requires:       cdemu-daemon >= 3.0.0
Requires:       python3-gobject-Gdk
Recommends:     %{name}-lang
Recommends:     typelib(AppIndicator3)
BuildArch:      noarch
%glib2_gsettings_schema_requires

%description
It provides a graphic interface that allows performing the key
tasks related to controlling the CDEmu daemon, such as loading and
unloading devices, displaying devices' status and
retrieving/setting devices' debug masks.

In addition, the application listens to signals emitted by
CDEmu daemon and provides notifications via libnotify (provided
that python bindings are installed).

Features:
 * GTK+ application.
 * Supports communication via either session or system bus.
 * Device status display, device loading and unloading.
 * Support for getting/setting device's debug masks.
 * Daemon and device status changes notification via libnotify.

%lang_package

%prep
%setup -q

%build
%cmake
%make_build

%install
%cmake_install
%suse_update_desktop_file -r %{name} System Filesystem
%find_lang %{name}

%post
%glib2_gsettings_schema_post

%postun
%glib2_gsettings_schema_postun

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}*
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon Nov 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.2.6:
  * If no AppIndicator3 is available try to load
    AyatanaAppIndicator3.
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.2.5
  * No upstream change log
* Sat May  2 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 3.2.4
* Sat Apr 18 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 3.2.1
  * Built against Python3
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 3.0.2:
  * Re-enable all translations.
    As only the fully-translated messages are really used, there is
    no harm in enabling the ones that are somewhat out-of-date,
    either. Re-generated all the .po files, and added language
    codes to the ones that were missing them.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 3.0.1:
  * Fix a typo that prevented switching of bad sector emulation.
  * In CMake Replace whitespaces in custom target names with "-"
    signs (silence CMP0037 warnings on CMake 3.2.2 and newer).
* Tue Oct 13 2015 sor.alexei@meowr.ru
- Correct dependencies.
- Change group to System/GUI/Other.
* Sun Jul 13 2014 sor.alexei@meowr.ru
- Initial package, version 3.0.0.
